document.addEventListener('DOMContentLoaded', () => {
  // Sample ISP plan data
  const plans = [
    {
      provider: 'FastNet',
      speed: 100,
      price: 49.99,
      features: ['No contract', 'Free installation']
    },
    {
      provider: 'SpeedWave',
      speed: 500,
      price: 79.99,
      features: ['Unlimited data', 'WiFi router included']
    },
    {
      provider: 'GigaConnect',
      speed: 1000,
      price: 99.99,
      features: ['24/7 support', 'Static IP']
    }
  ];

  // Mobile menu toggle
  const mobileMenu = document.querySelector('.mobile-menu');
  const navLinks = document.querySelector('.nav-links');
  
  mobileMenu.addEventListener('click', () => {
    navLinks.style.display = navLinks.style.display === 'flex' ? 'none' : 'flex';
  });

  // ZIP code validation
  const zipInput = document.getElementById('zipcode');
  const searchBtn = document.getElementById('search-btn');

  zipInput.addEventListener('input', (e) => {
    e.target.value = e.target.value.replace(/[^0-9]/g, '');
  });

  searchBtn.addEventListener('click', () => {
    const zip = zipInput.value;
    if (zip.length === 5) {
      displayPlans(plans);
    } else {
      alert('Please enter a valid 5-digit ZIP code');
    }
  });

  // Filter functionality
  const speedFilter = document.getElementById('speed-filter');
  const priceFilter = document.getElementById('price-filter');

  [speedFilter, priceFilter].forEach(filter => {
    filter.addEventListener('change', () => {
      let filteredPlans = [...plans];
      
      if (speedFilter.value) {
        filteredPlans = filteredPlans.filter(plan => 
          plan.speed >= parseInt(speedFilter.value)
        );
      }
      
      if (priceFilter.value) {
        filteredPlans = filteredPlans.filter(plan => 
          plan.price <= parseInt(priceFilter.value)
        );
      }
      
      displayPlans(filteredPlans);
    });
  });

  // Display plans
  function displayPlans(plansToShow) {
    const container = document.getElementById('plans-container');
    container.innerHTML = '';

    plansToShow.forEach(plan => {
      const planElement = document.createElement('div');
      planElement.className = 'feature';
      planElement.innerHTML = `
        <h3>${plan.provider}</h3>
        <p>${plan.speed} Mbps</p>
        <p>$${plan.price}/month</p>
        <ul>
          ${plan.features.map(feature => `<li>${feature}</li>`).join('')}
        </ul>
        <button>Select Plan</button>
      `;
      container.appendChild(planElement);
    });
  }
});
